@@ -3,52 +3,56 @@
     pygments.lexers._csound_builtins
     ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
-    :copyright: Copyright 2006-2019 by the Pygments team, see AUTHORS.
+    :copyright: Copyright 2006-2020 by the Pygments team, see AUTHORS.
     :license: BSD, see LICENSE for details.
 """
 
-# Opcodes in Csound 6.12.0 at commit 6ca322bd31f1ca907c008616b40a5f237ff449db using
-#   python -c "
-#   import re, subprocess
-#   output = subprocess.Popen(['csound', '--list-opcodes0'], stderr=subprocess.PIPE).communicate()[1]
-#   opcodes = output[re.search(r'^$', output, re.M).end():re.search(r'^\d+ opcodes$', output, re.M).start()].split()
-#   output = subprocess.Popen(['csound', '--list-opcodes2'], stderr=subprocess.PIPE).communicate()[1]
-#   all_opcodes = output[re.search(r'^$', output, re.M).end():re.search(r'^\d+ opcodes$', output, re.M).start()].split()
+# Opcodes in Csound 6.14.0 using:
+#   python3 -c "
+#   import re
+#   from subprocess import Popen, PIPE
+#   output = Popen(['csound', '--list-opcodes0'], stderr=PIPE, text=True).communicate()[1]
+#   opcodes = output[re.search(r'^\$', output, re.M).end() : re.search(r'^\d+ opcodes\$', output, re.M).start()].split()
+#   output = Popen(['csound', '--list-opcodes2'], stderr=PIPE, text=True).communicate()[1]
+#   all_opcodes = output[re.search(r'^\$', output, re.M).end() : re.search(r'^\d+ opcodes\$', output, re.M).start()].split()
 #   deprecated_opcodes = [opcode for opcode in all_opcodes if opcode not in opcodes]
-#   print '''OPCODES = set(\'''
-#   {}
+#   # Remove opcodes that csound.py treats as keywords.
+#   keyword_opcodes = [
+#       'cggoto',   # https://csound.com/docs/manual/cggoto.html
+#       'cigoto',   # https://csound.com/docs/manual/cigoto.html
+#       'cingoto',  # (undocumented)
+#       'ckgoto',   # https://csound.com/docs/manual/ckgoto.html
+#       'cngoto',   # https://csound.com/docs/manual/cngoto.html
+#       'cnkgoto',  # (undocumented)
+#       'endin',    # https://csound.com/docs/manual/endin.html
+#       'endop',    # https://csound.com/docs/manual/endop.html
+#       'goto',     # https://csound.com/docs/manual/goto.html
+#       'igoto',    # https://csound.com/docs/manual/igoto.html
+#       'instr',    # https://csound.com/docs/manual/instr.html
+#       'kgoto',    # https://csound.com/docs/manual/kgoto.html
+#       'loop_ge',  # https://csound.com/docs/manual/loop_ge.html
+#       'loop_gt',  # https://csound.com/docs/manual/loop_gt.html
+#       'loop_le',  # https://csound.com/docs/manual/loop_le.html
+#       'loop_lt',  # https://csound.com/docs/manual/loop_lt.html
+#       'opcode',   # https://csound.com/docs/manual/opcode.html
+#       'reinit',   # https://csound.com/docs/manual/reinit.html
+#       'return',   # https://csound.com/docs/manual/return.html
+#       'rireturn', # https://csound.com/docs/manual/rireturn.html
+#       'rigoto',   # https://csound.com/docs/manual/rigoto.html
+#       'tigoto',   # https://csound.com/docs/manual/tigoto.html
+#       'timout'    # https://csound.com/docs/manual/timout.html
+#   ]
+#   opcodes = [opcode for opcode in opcodes if opcode not in keyword_opcodes]
+#   newline = '\n'
+#   print(f'''OPCODES = set(\'''
+#   {newline.join(opcodes)}
 #   \'''.split())
 #
 #   DEPRECATED_OPCODES = set(\'''
-#   {}
+#   {newline.join(deprecated_opcodes)}
 #   \'''.split())
-#   '''.format('\n'.join(opcodes), '\n'.join(deprecated_opcodes))
+#   ''')
 #   "
-# except for
-#   cggoto   csound.com/docs/manual/cggoto.html
-#   cigoto   csound.com/docs/manual/cigoto.html
-#   cingoto  (undocumented)
-#   ckgoto   csound.com/docs/manual/ckgoto.html
-#   cngoto   csound.com/docs/manual/cngoto.html
-#   cnkgoto  (undocumented)
-#   endin    csound.com/docs/manual/endin.html
-#   endop    csound.com/docs/manual/endop.html
-#   goto     csound.com/docs/manual/goto.html
-#   igoto    csound.com/docs/manual/igoto.html
-#   instr    csound.com/docs/manual/instr.html
-#   kgoto    csound.com/docs/manual/kgoto.html
-#   loop_ge  csound.com/docs/manual/loop_ge.html
-#   loop_gt  csound.com/docs/manual/loop_gt.html
-#   loop_le  csound.com/docs/manual/loop_le.html
-#   loop_lt  csound.com/docs/manual/loop_lt.html
-#   opcode   csound.com/docs/manual/opcode.html
-#   reinit   csound.com/docs/manual/reinit.html
-#   return   csound.com/docs/manual/return.html
-#   rireturn csound.com/docs/manual/rireturn.html
-#   rigoto   csound.com/docs/manual/rigoto.html
-#   tigoto   csound.com/docs/manual/tigoto.html
-#   timout   csound.com/docs/manual/timout.html
-# which are treated as keywords in csound.py.
 
 OPCODES = set('''
 ATSadd
@@ -169,8 +173,8 @@ STKBowed
 STKBrass
 STKClarinet
 STKDrummer
-STKFlute
 STKFMVoices
+STKFlute
 STKHevyMetl
 STKMandolin
 STKModalBar
@@ -196,12 +200,18 @@ adsyn
 adsynt
 adsynt2
 aftouch
+allpole
 alpass
 alwayson
 ampdb
 ampdbfs
 ampmidi
+ampmidicurve
 ampmidid
+apoleparams
+arduinoRead
+arduinoStart
+arduinoStop
 areson
 aresonk
 atone
@@ -224,6 +234,7 @@ binit
 biquad
 biquada
 birnd
+bob
 bpf
 bpfcos
 bqrez
@@ -249,7 +260,6 @@ centroid
 ceps
 cepsinv
 chanctrl
-changed
 changed2
 chani
 chano
@@ -261,11 +271,19 @@ chn_k
 chnclear
 chnexport
 chnget
+chngeta
+chngeti
+chngetk
 chngetks
+chngets
 chnmix
 chnparams
 chnset
+chnseta
+chnseti
+chnsetk
 chnsetks
+chnsets
 chuap
 clear
 clfilt
@@ -274,6 +292,11 @@ clockoff
 clockon
 cmp
 cmplxprod
+cntCreate
+cntCycles
+cntRead
+cntReset
+cntState
 comb
 combinv
 compilecsd
@@ -293,6 +316,8 @@ cosinv
 cosseg
 cossegb
 cossegr
+count
+count_i
 cps2pch
 cpsmidi
 cpsmidib
@@ -418,6 +443,17 @@ flashtxt
 flooper
 flooper2
 floor
+fluidAllOut
+fluidCCi
+fluidCCk
+fluidControl
+fluidEngine
+fluidInfo
+fluidLoad
+fluidNote
+fluidOut
+fluidProgramSelect
+fluidSetInterpMethod
 fmanal
 fmax
 fmb3
@@ -452,6 +488,7 @@ ftaudio
 ftchnls
 ftconv
 ftcps
+ftexists
 ftfree
 ftgen
 ftgenonce
@@ -468,7 +505,9 @@ ftresizei
 ftsamplebank
 ftsave
 ftsavek
+ftset
 ftslice
+ftslicei
 ftsr
 gain
 gainslider
@@ -492,6 +531,7 @@ grain
 grain2
 grain3
 granule
+gtf
 guiro
 harmon
 harmon2
@@ -599,6 +639,10 @@ la_i_multiply_mc
 la_i_multiply_mr
 la_i_multiply_vc
 la_i_multiply_vr
+la_i_norm1_mc
+la_i_norm1_mr
+la_i_norm1_vc
+la_i_norm1_vr
 la_i_norm_euclid_mc
 la_i_norm_euclid_mr
 la_i_norm_euclid_vc
@@ -609,10 +653,6 @@ la_i_norm_inf_vc
 la_i_norm_inf_vr
 la_i_norm_max_mc
 la_i_norm_max_mr
-la_i_norm1_mc
-la_i_norm1_mr
-la_i_norm1_vc
-la_i_norm1_vr
 la_i_print_mc
 la_i_print_mr
 la_i_print_vc
@@ -697,6 +737,10 @@ la_k_multiply_mc
 la_k_multiply_mr
 la_k_multiply_vc
 la_k_multiply_vr
+la_k_norm1_mc
+la_k_norm1_mr
+la_k_norm1_vc
+la_k_norm1_vr
 la_k_norm_euclid_mc
 la_k_norm_euclid_mr
 la_k_norm_euclid_vc
@@ -707,10 +751,6 @@ la_k_norm_inf_vc
 la_k_norm_inf_vr
 la_k_norm_max_mc
 la_k_norm_max_mr
-la_k_norm1_mc
-la_k_norm1_mr
-la_k_norm1_vc
-la_k_norm1_vr
 la_k_qr_eigen_mc
 la_k_qr_eigen_mr
 la_k_qr_factor_mc
@@ -732,6 +772,9 @@ la_k_upper_solve_mc
 la_k_upper_solve_mr
 la_k_vc_set
 la_k_vr_set
+lag
+lagud
+lastcycle
 lenarray
 lfo
 limit
@@ -777,6 +820,8 @@ loscilx
 lowpass2
 lowres
 lowresx
+lpcanal
+lpcfilter
 lpf18
 lpform
 lpfreson
@@ -800,6 +845,7 @@ lua_ikopcall_off
 lua_iopcall
 lua_iopcall_off
 lua_opdef
+lufs
 mac
 maca
 madsr
@@ -822,6 +868,7 @@ mdelay
 median
 mediank
 metro
+metro2
 mfb
 midglobal
 midiarp
@@ -900,6 +947,8 @@ nrpn
 nsamp
 nstance
 nstrnum
+nstrstr
+ntof
 ntom
 ntrpol
 nxtpow2
@@ -1024,13 +1073,11 @@ printk
 printk2
 printks
 printks2
+println
 prints
+printsk
 product
 pset
-ptable
-ptable3
-ptablei
-ptableiw
 ptablew
 ptrack
 puts
@@ -1047,6 +1094,7 @@ pvsanal
 pvsarp
 pvsbandp
 pvsbandr
+pvsbandwidth
 pvsbin
 pvsblur
 pvsbuffer
@@ -1055,6 +1103,7 @@ pvsbufread2
 pvscale
 pvscent
 pvsceps
+pvscfs
 pvscross
 pvsdemix
 pvsdiskin
@@ -1074,6 +1123,7 @@ pvsin
 pvsinfo
 pvsinit
 pvslock
+pvslpc
 pvsmaska
 pvsmix
 pvsmooth
@@ -1175,6 +1225,7 @@ qinf
 qnan
 r2c
 rand
+randc
 randh
 randi
 random
@@ -1198,6 +1249,7 @@ remove
 repluck
 reshapearray
 reson
+resonbnk
 resonk
 resonr
 resonx
@@ -1215,6 +1267,7 @@ rifft
 rms
 rnd
 rnd31
+rndseed
 round
 rspline
 rtclock
@@ -1235,6 +1288,7 @@ scanu
 schedkwhen
 schedkwhennamed
 schedule
+schedulek
 schedwhen
 scoreline
 scoreline_i
@@ -1322,6 +1376,7 @@ spsend
 sqrt
 squinewave
 statevar
+sterrain
 stix
 strcat
 strcatk
@@ -1337,6 +1392,7 @@ strfromurl
 strget
 strindex
 strindexk
+string2array
 strlen
 strlenk
 strlower
@@ -1344,6 +1400,7 @@ strlowerk
 strrindex
 strrindexk
 strset
+strstrip
 strsub
 strsubk
 strtod
@@ -1380,7 +1437,6 @@ tableicopy
 tableigpw
 tableikt
 tableimix
-tableiw
 tablekt
 tablemix
 tableng
@@ -1432,6 +1488,8 @@ trcross
 trfilter
 trhighest
 trigger
+trighold
+trigphasor
 trigseq
 trim
 trim_i
@@ -1514,6 +1572,7 @@ vpow
 vpow_i
 vpowv
 vpowv_i
+vps
 vpvoc
 vrandh
 vrandi
@@ -1589,6 +1648,7 @@ DEPRECATED_OPCODES = set('''
 array
 bformdec
 bformenc
+changed
 copy2ftab
 copy2ttab
 hrtfer
@@ -1598,6 +1658,10 @@ maxtab
 mintab
 pop
 pop_f
+ptable
+ptable3
+ptablei
+ptableiw
 push
 push_f
 scalet
@@ -1616,6 +1680,7 @@ spectrum
 stack
 sumtab
 tabgen
+tableiw
 tabmap
 tabmap_i
 tabslice
